Saving figures as GIF works again
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

According to the figure documentation, the ``savefig`` method supports the
GIF format with the file extension ``.gif``. However, GIF support had been
broken since Matplotlib 2.0.0. It works again.
